use clap::{Arg, ArgAction, ArgMatches, Command};
use octopush_infra::service_register::ServiceRegister;

pub fn execute_cmd() -> Command {
    Command::new("execute")
        .about("execute a certain action")
        .arg(
            Arg::new("action")
                .long("action")
                .short('a')
                .action(ArgAction::Set)
                .help("action path to your local octopush.yaml file")
                .long_help("action path to your local octopush.yaml file")
                .required(true),
        )
}

pub async fn execute_subcommand(args: &ArgMatches) -> eyre::Result<()> {
    let action = args
        .get_one::<String>("action")
        .ok_or(eyre::anyhow!("--action is required"))?;

    let service_register = ServiceRegister::new();

    service_register
        .git_provider
        .clone_from_url("https://git.front.kjuulh.io/kjuulh/cuddle".to_string())
        .await?;

    service_register.cleanup().await?;

    Ok(())
}
